@@ -1,16 +1,14 @@
 //! BAM record data and fields.
 
 pub mod field;
-pub mod reader;
+mod fields;
 
-pub use self::{field::Field, reader::Reader};
+pub use self::{field::Field, fields::Fields};
 
 use std::{convert::TryFrom, error, fmt, ops::Deref};
 
 use noodles_sam as sam;
 
-use self::reader::Fields;
-
 /// BAM record data.
 ///
 /// This is also called optional fields.
@@ -24,10 +22,9 @@ impl<'a> Data<'a> {
     /// ```
     /// use noodles_bam::record::Data;
     ///
-    /// // NH:i:1  RG:Z:rg0
     /// let raw_data = [
-    ///     0x4e, 0x48, 0x69, 0x01, 0x00, 0x00, 0x00,
-    ///     0x52, 0x47, 0x5a, 0x72, 0x67, 0x30, 0x00,
+    ///     b'N', b'H', b'i', 0x01, 0x00, 0x00, 0x00, // NH:i:1
+    ///     b'R', b'G', b'Z', b'r', b'g', b'0', 0x00, // RG:Z:rg0
     /// ];
     /// let data = Data::new(&raw_data);
     /// ```
@@ -44,27 +41,29 @@ impl<'a> Data<'a> {
     /// use noodles_bam::record::{data::{field::Value, Field}, Data};
     /// use noodles_sam::record::data::field::Tag;
     ///
-    /// // NH:i:1  RG:Z:rg0
     /// let raw_data = [
-    ///     0x4e, 0x48, 0x69, 0x01, 0x00, 0x00, 0x00,
-    ///     0x52, 0x47, 0x5a, 0x72, 0x67, 0x30, 0x00,
+    ///     b'N', b'H', b'i', 0x01, 0x00, 0x00, 0x00, // NH:i:1
+    ///     b'R', b'G', b'Z', b'r', b'g', b'0', 0x00, // RG:Z:rg0
     /// ];
     /// let data = Data::new(&raw_data);
     ///
     /// let mut fields = data.fields();
     ///
-    /// let field = fields.next().unwrap()?;
-    /// assert_eq!(field, Field::new(Tag::AlignmentHitCount, Value::Int32(1)));
+    /// assert_eq!(
+    ///     fields.next().transpose()?,
+    ///     Some(Field::new(Tag::AlignmentHitCount, Value::Int32(1)))
+    /// );
     ///
-    /// let field = fields.next().unwrap()?;
-    /// assert_eq!(field, Field::new(Tag::ReadGroup, Value::String(String::from("rg0"))));
+    /// assert_eq!(
+    ///     fields.next().transpose()?,
+    ///     Some(Field::new(Tag::ReadGroup, Value::String(String::from("rg0"))))
+    /// );
     ///
     /// assert!(fields.next().is_none());
     /// # Ok::<(), io::Error>(())
     /// ```
     pub fn fields(&self) -> Fields<&[u8]> {
-        let reader = Reader::new(self.0);
-        reader.fields()
+        Fields::new(self.0)
     }
 }
 
@@ -129,8 +128,8 @@ mod tests {
         };
 
         let raw_data = [
-            0x4e, 0x48, 0x69, 0x01, 0x00, 0x00, 0x00, // NH:i:1
-            0x52, 0x47, 0x5a, 0x72, 0x67, 0x30, 0x00, // RG:Z:rg0
+            b'N', b'H', b'i', 0x01, 0x00, 0x00, 0x00, // NH:i:1
+            b'R', b'G', b'Z', b'r', b'g', b'0', 0x00, // RG:Z:rg0
         ];
         let data = Data::new(&raw_data);
 
